==> blender-2.31.tar.gz: blender-2.31/source/blender/render/intern/include/initrender.h <==
/*
 * initrender_ext.h
 *
 * $Id: initrender.h,v 1.4 2002/12/27 13:10:33 mein Exp $
 *
 * ***** BEGIN GPL/BL DUAL LICENSE BLOCK *****
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version. The Blender
 * Foundation also sells licenses for use in proprietary software under
 * the Blender License.  See http://www.blender.org/BL/ for information
 * about this.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * The Original Code is Copyright (C) 2001-2002 by NaN Holding BV.
 * All rights reserved.
 *
 * The Original Code is: all of this file.
 *
 * Contributor(s): none yet.
 *
 * ***** END GPL/BL DUAL LICENSE BLOCK *****
 */

#ifndef INITRENDER_EXT_H
#define INITRENDER_EXT_H 

/* type includes */

#include "DNA_effect_types.h"        /* for PartEff type */
#include "render_types.h"

/* Functions */

void init_def_material(void);
void init_render_jit(int nr);
float  calc_weight(float *weight, int i, int j);
void defaultlamp(void);
void schrijfplaatje(char *name);
void initparts(void);
short setpart(short nr); /* return 0 als geen goede part */
void addparttorect(short nr, Part *part);
void add_to_blurbuf(int blur);
void oldRenderLoop(void); /* Calls the old renderer. Contains the PART and FIELD loops. */
void render(void);  /* Switch between the old and the unified renderer. */
/*  void write_screendump(char *name); not here !*/

#endif /* INITRENDER_EXT_H */

==> blender-2.44.tar.gz: blender-2.44/source/blender/render/intern/include/initrender.h <==
/*
 * initrender_ext.h
 *
 * $Id: initrender.h,v 1.6 2006/01/28 18:33:16 hos Exp $
 *
 * ***** BEGIN GPL/BL DUAL LICENSE BLOCK *****
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version. The Blender
 * Foundation also sells licenses for use in proprietary software under
 * the Blender License.  See http://www.blender.org/BL/ for information
 * about this.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * The Original Code is Copyright (C) 2001-2002 by NaN Holding BV.
 * All rights reserved.
 *
 * The Original Code is: all of this file.
 *
 * Contributor(s): none yet.
 *
 * ***** END GPL/BL DUAL LICENSE BLOCK *****
 */

#ifndef INITRENDER_H
#define INITRENDER_H 

struct Object;

/* Functions */

void free_sample_tables(Render *re);
void make_sample_tables(Render *re);

void render_scene_set_window(Render *re, struct Object *camera, int blursample);

void initparts(Render *re);
void freeparts(Render *re);


#endif /* INITRENDER_H */
